```
Usage: vcd gateway services firewall delete-destination [OPTIONS] <name> <id>
                                                        <destination_value>

Options:
  -h, --help  Show this message and exit.

```
